package com.example.demo.exception;

import com.example.demo.pojo.ResponseMessage;
import jakarta.servlet.http.HttpServlet;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.validation.ValidationException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;
import org.springframework.web.servlet.resource.NoResourceFoundException;

@RestControllerAdvice
public class GlobalHttpExceptionHandlerAdvice {
    Logger logger = LoggerFactory.getLogger(GlobalHttpExceptionHandlerAdvice.class);


    @ExceptionHandler({Exception.class})
    public ResponseMessage<String> handleException(Exception e, HttpServletRequest request, HttpServletResponse response) {
//        如果是 ValidationException，则返回 400 Bad Request
        if (e instanceof MethodArgumentNotValidException) {
            response.setStatus(HttpStatus.BAD_REQUEST.value());
            return ResponseMessage.fail(e.getMessage());
        }

        // NoResourceFoundException
        if (e instanceof NoResourceFoundException) {
            response.setStatus(HttpStatus.NOT_FOUND.value());
            return ResponseMessage.notFound(e.getMessage());
        }

//        get type of e
        logger.error("Server Error, {}, Error: {}", e.getClass().getName(), e.getMessage());

        response.setStatus(HttpStatus.INTERNAL_SERVER_ERROR.value());

        return ResponseMessage.fail("Internal Server Error");
    }
}
